==> service-common-2.9.2-20161205.023958-2-sources.jar: com/baijia/tianxiao/excel/ExcelExporterUtils.java <==
package com.baijia.tianxiao.excel;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.PushbackInputStream;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.ConvertUtils;
import org.apache.commons.beanutils.PropertyUtilsBean;
import org.apache.commons.beanutils.locale.converters.DateLocaleConverter;
import org.apache.commons.io.IOUtils;
import org.apache.commons.io.output.ByteArrayOutputStream;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.DataFormat;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.collect.Maps;

import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;

/**
 * @author cxm
 * @version 1.0
 * @title ExcelExporterUtils
 * @desc TODO
 * @date 2015年12月2日
 */
@Slf4j
public class ExcelExporterUtils {

    /**
     *
     */
    private static final String EXPORT_CELL_STYLS = "export_cell_styls_";

    private static final Logger logger = LoggerFactory.getLogger(ExcelExporterUtils.class);

    public static final String EXPORT_DATE_FORMAT = "yyyy-MM-dd HH:mm:ss";

    public static PropertyUtilsBean propertyUtilsBean = new PropertyUtilsBean();

    public static List<Object[]> read(File file, int sheetNum) {
        Workbook wb = null;
        InputStream in = null;
        try {
            in = new PushbackInputStream(new FileInputStream(file), 8);
            return read(in, sheetNum);
        } catch (Exception e) {
            throw new RuntimeException("read excel exception - ", e);
        } finally {
            IOUtils.closeQuietly(wb);
            IOUtils.closeQuietly(in);
        }
    }

    public static List<Object[]> read(@NonNull InputStream in, int sheetNum) {
        Workbook wb = null;
        try {
            if (!(in instanceof PushbackInputStream)) {
                in = new PushbackInputStream(in, 8);
            }

            if (POIFSFileSystem.hasPOIFSHeader(in)) {
                wb = new HSSFWorkbook(in);
            } else {
                wb = new XSSFWorkbook(in);
            }
            Sheet sheet = wb.getSheetAt(sheetNum);
            return getTable(sheet);
        } catch (Exception e) {
            throw new RuntimeException("read excel exception - ", e);
        } finally {
            IOUtils.closeQuietly(wb);
            IOUtils.closeQuietly(in);
        }
    }

    private static List<Object[]> getTable(Sheet sheet) {
        logger.trace("sheet:{}, firstRowNum:{}, lastRowNum:{}", sheet.getSheetName(), sheet.getFirstRowNum(),
                sheet.getLastRowNum());
        List<Object[]> list = new ArrayList<>(sheet.getLastRowNum() + 1);
        int columnCount = 0;
        for (int r = sheet.getFirstRowNum(); r <= sheet.getLastRowNum(); r++) {
            Row row = sheet.getRow(r);
            if (row == null) {
                logger.trace("row:{}, null", r);
            } else {
                logger.trace("row:{}, firstCellNum:{}, lastCellNum:{}", row.getRowNum(), row.getFirstCellNum(),
                        row.getLastCellNum());
                if (row.getLastCellNum() <= 0) {
                    continue;
                }
                if (columnCount == 0) {
                    columnCount = row.getLastCellNum();
                }
                Object[] rowObj = new Object[columnCount];
                boolean hasValueRow = false;
                for (int c = row.getFirstCellNum(); c < row.getLastCellNum(); c++) {
                    Cell cell = row.getCell(c);
                    logger.trace("row:{}, cell:{}, value:{}", row.getRowNum(), c, cell);
                    rowObj[c] = getValueFromCell(cell);
                    if (!hasValueRow && (rowObj[c] != null && StringUtils.isNoneBlank(rowObj[c].toString()))) {
                        hasValueRow = true;
                    }
                }
                if (hasValueRow) {
                    list.add(rowObj);
                }
            }
        }
        return list;
    }

    public static final Object getValueFromCell(Cell cell) {
        if (cell == null) {
            return StringUtils.EMPTY;
        }
        Object value = null;
        switch (cell.getCellType()) {
            case Cell.CELL_TYPE_NUMERIC:
                if (DateUtil.isCellDateFormatted(cell)) {
                    value = cell.getDateCellValue();
                } else {
                    String cellFormat = cell.getCellStyle().getDataFormatString();
                    value = cell.getNumericCellValue();
                    if ("General".equals(cellFormat) || "@".equals(cellFormat)) {
                        cellFormat = "0";
                        DecimalFormat format = new DecimalFormat(cellFormat);
                        value = format.format(cell.getNumericCellValue());
                    }
                    
                }

                break;
            case Cell.CELL_TYPE_STRING:
                value = cell.getStringCellValue();

                break;
            case Cell.CELL_TYPE_FORMULA:
                double numericValue = cell.getNumericCellValue();
                if (DateUtil.isValidExcelDate(numericValue)) { // 如果是日期类型
                    value = cell.getDateCellValue();
                } else {
                    value = String.valueOf(numericValue);
                    // System.out.println("formula value:" + value);
                }
                break;
            case Cell.CELL_TYPE_BLANK:
                value = StringUtils.EMPTY;
                break;
            case Cell.CELL_TYPE_BOOLEAN: // Boolean
                value = String.valueOf(cell.getBooleanCellValue());
                break;
            case Cell.CELL_TYPE_ERROR: // Error，返回错误码
                value = String.valueOf(cell.getErrorCellValue());
                break;
            default:
                value = StringUtils.EMPTY;
                break;
        }
        return value;
    }

    public static <T> void exportToExcel(HttpServletResponse response, List<T> data, String[] fields,
                                         String[] fieldValue) {
        exportToExcel(response, data, fields, fieldValue, null);
    }

    public static <T> void exportToExcel(HttpServletResponse response, List<T> data, String[] fields,
                                         String[] fieldValue, String fileName) {

        if (fileName == null || "".equals(fileName)) {
            fileName = System.currentTimeMillis() + ".xlsx";
        }

        response.setContentType("application/vnd.ms-excel");
        try {
            response.setHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(fileName, "utf-8"));
        } catch (UnsupportedEncodingException e1) {
            response.setHeader("Content-Disposition", "attachment; filename=" + fileName);
        }

        try {
            exportToExcel(response.getOutputStream(), data, fields, fieldValue);
        } catch (IOException e) {
            throw new RuntimeException("export data error", e);
        }
    }

    public static <T> ZipOutputStream getZipOutputStream(HttpServletResponse response, String fileName)
            throws IOException {

        if (fileName == null || "".equals(fileName)) {
            fileName = System.currentTimeMillis() + ".zip";
        }

        response.setContentType("application/zip");
        response.setHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(fileName, "utf-8"));
        ConvertUtils.register(new DateLocaleConverter(Locale.CHINA), Date.class);
        ZipOutputStream out = new ZipOutputStream(response.getOutputStream());
        return out;
    }

    public static <T> void exportToZip(ZipOutputStream out, List<T> data, String[] fields, String[] fieldValue,
                                       String fileName) {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        try {
            exportToExcel(baos, data, fields, fieldValue);

            out.putNextEntry(new ZipEntry("./tianxiao_export/" + fileName + ".xlsx"));
            out.write(baos.toByteArray());
            out.flush();
            out.closeEntry();
        } catch (IOException e) {
            throw new RuntimeException("export data error", e);
        } finally {
            IOUtils.closeQuietly(baos);
        }
    }

    public static <T> void closeZipOutputStream(ZipOutputStream out) {
        if (out != null) {
            try {
                out.flush();
                out.close();
            } catch (IOException e) {
            }
        }
    }

    private static CellStyle createCellStyle(Workbook workBook, String format, Map<String, CellStyle> cellStyleMap) {
        String key = EXPORT_CELL_STYLS + format;
        CellStyle cellStyle = cellStyleMap.get(key);
        if (cellStyle == null) {
            DataFormat dataFormat = workBook.createDataFormat();
            cellStyle = workBook.createCellStyle();
            cellStyle.setAlignment(CellStyle.ALIGN_CENTER);
            cellStyle.setDataFormat(dataFormat.getFormat(format));
            cellStyleMap.put(key, cellStyle);
        }
        return cellStyle;

    }

    private static void createCell(Sheet sheet, Row row, int column, Object value,
                                   Map<String, CellStyle> cellStyleMap) {
        Cell cell = row.createCell(column);

        if (value != null) {
            String format = null;
            if (value instanceof Date) {
                sheet.setColumnWidth(cell.getColumnIndex(), 20 * 256);
                format = EXPORT_DATE_FORMAT;
                cell.setCellValue((Date) value);
            } else {
                if (value instanceof Number && (((Number) value).longValue() < Integer.MAX_VALUE)) {
                    cell.setCellType(Cell.CELL_TYPE_NUMERIC);
                    if (value instanceof Double) {
                        format = "0.00";
                        cell.setCellValue(((Number) value).doubleValue());
                    } else {
                        format = "0";
                        cell.setCellValue(((Number) value).longValue());
                    }
                } else {
                    cell.setCellType(Cell.CELL_TYPE_STRING);
                    cell.setCellValue(value.toString());
                    format = "@";
                }
            }
            if (format != null) {
                cell.setCellStyle(createCellStyle(sheet.getWorkbook(), format, cellStyleMap));
            }
        } else {
            cell.setCellValue("");
        }
    }

    public static <T> void exportToExcel(OutputStream os, List<T> data, String[] fields, String[] fieldValue) {
        if (fields == null || fieldValue == null) {
            throw new RuntimeException("fields or header can't be null.");
        }
        Workbook wb = new XSSFWorkbook();
        Sheet sheet = wb.createSheet("ExportDataList");

        // Create a row and put some cells in it. Rows are 0 based.
        Row headerTitle = sheet.createRow(0);
        int index = 0;
        for (int i = 0; i < fields.length; i++) {
            Cell cell = headerTitle.createCell(index++ % fields.length);
            cell.setCellValue(fieldValue[i]);
            sheet.setColumnWidth(cell.getColumnIndex(), fieldValue[i].length() * 8 * 256);
            cell.getCellStyle().setAlignment(CellStyle.ALIGN_CENTER);
        }

        logger.debug("exportToExcel data size={}", data.size());
        try {
            Map<String, CellStyle> cellStyleMap = Maps.newHashMap();
            for (int i = 0; i < data.size(); i++) {
                Row row = sheet.createRow(i + 1);
                T o = data.get(i);

                for (int j = 0; j < fields.length; j++) {
                    try {
                        createCell(sheet, row, index++ % fields.length, propertyUtilsBean.getProperty(o, fields[j]),
                                cellStyleMap);
                    } catch (Exception e) {
                        e.printStackTrace();
                        throw new RuntimeException("export data error", e);
                    }

                }
            }
            wb.write(os);
            os.flush();
        } catch (IOException e) {
            throw new RuntimeException("export data error", e);
        } finally {
            IOUtils.closeQuietly(wb);
        }
    }

    public static void fillSheet(Sheet sheet, List<String> headers, Collection<Object[]> datas,
                                 Map<String, CellStyle> cellStyleMap) {
        Row headerTitle = sheet.createRow(0);
        int index = 0;
        for (int i = 0; i < headers.size(); i++) {
            String name = headers.get(i);
            int column = index++ % headers.size();
            sheet.setColumnWidth(column, name.length() * 2 * 256);
            Cell cell = headerTitle.createCell(column);
            cell.setCellValue(name);
            cell.getCellStyle().setAlignment(CellStyle.ALIGN_CENTER);
        }

        int i = 0;
        if (cellStyleMap == null) {
            cellStyleMap = Maps.newHashMap();
        }
        for (Object[] o : datas) {
            Row row = sheet.createRow(i + 1);

            for (int j = 0; j < o.length; j++) {
                try {
                    createCell(sheet, row, index++ % o.length, o[j], cellStyleMap);
                } catch (Exception e) {
                    throw new RuntimeException("export data error", e);
                }
            }
            i++;
        }
    }

    public static <T> void fillSheet(Sheet sheet, Collection<T> data, String[] fields, String[] fieldValue,
                                     Map<String, CellStyle> cellStyleMap) {
        // Create a row and put some cells in it. Rows are 0 based.
        Row headerTitle = sheet.createRow(0);
        int index = 0;
        for (int i = 0; i < fields.length; i++) {
            int column = index++ % fields.length;
            sheet.setColumnWidth(column, fieldValue[i].length() * 2 * 256);
            Cell cell = headerTitle.createCell(column);
            cell.setCellValue(fieldValue[i]);
            cell.getCellStyle().setAlignment(CellStyle.ALIGN_CENTER);
        }

        int i = 0;
        if (cellStyleMap == null) {
            cellStyleMap = Maps.newHashMap();
        }
        for (T o : data) {
            Row row = sheet.createRow(i + 1);

            for (int j = 0; j < fields.length; j++) {
                try {
                    createCell(sheet, row, index++ % fields.length, propertyUtilsBean.getProperty(o, fields[j]),
                            cellStyleMap);
                } catch (Exception e) {
                    throw new RuntimeException("export data error", e);
                }
            }
            i++;
        }
    }

}

==> service-common-2.24.0-20170428.014318-47-sources.jar: com/baijia/tianxiao/excel/ExcelExporterUtils.java <==
package com.baijia.tianxiao.excel;

import com.google.common.base.CharMatcher;
import com.google.common.collect.Maps;

import org.apache.commons.beanutils.ConvertUtils;
import org.apache.commons.beanutils.PropertyUtilsBean;
import org.apache.commons.beanutils.locale.converters.DateLocaleConverter;
import org.apache.commons.io.IOUtils;
import org.apache.commons.io.output.ByteArrayOutputStream;
import org.apache.commons.lang3.StringEscapeUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.DataFormat;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.PushbackInputStream;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

import javax.servlet.http.HttpServletResponse;

import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;

/**
 * @author cxm
 * @version 1.0
 * @title ExcelExporterUtils
 * @desc TODO
 * @date 2015年12月2日
 */
@Slf4j
public class ExcelExporterUtils {

    /**
     *
     */
    private static final String EXPORT_CELL_STYLS = "export_cell_styls_";

    private static final Logger logger = LoggerFactory.getLogger(ExcelExporterUtils.class);

    public static final String EXPORT_DATE_FORMAT = "yyyy-MM-dd HH:mm:ss";

    public static PropertyUtilsBean propertyUtilsBean = new PropertyUtilsBean();

    public static List<Object[]> read(File file, int sheetNum) {
        Workbook wb = null;
        InputStream in = null;
        try {
            in = new PushbackInputStream(new FileInputStream(file), 8);
            return read(in, sheetNum);
        } catch (Exception e) {
            throw new RuntimeException("read excel exception - ", e);
        } finally {
            IOUtils.closeQuietly(wb);
            IOUtils.closeQuietly(in);
        }
    }

    public static List<Object[]> read(@NonNull InputStream in, int sheetNum) {
        Workbook wb = null;
        try {
            if (!(in instanceof PushbackInputStream)) {
                in = new PushbackInputStream(in, 8);
            }

            if (POIFSFileSystem.hasPOIFSHeader(in)) {
                wb = new HSSFWorkbook(in);
            } else {
                wb = new XSSFWorkbook(in);
            }
            Sheet sheet = wb.getSheetAt(sheetNum);
            return getTable(sheet);
        } catch (Exception e) {
            throw new RuntimeException("read excel exception - ", e);
        } finally {
            IOUtils.closeQuietly(wb);
            IOUtils.closeQuietly(in);
        }
    }

    public static String filterExcelSheetKeyword(String str){
        String replaceStr;
        try {
            String unescapeStr = StringEscapeUtils.unescapeJava(str);
            replaceStr = CharMatcher.anyOf(":\\/?*[]：／？＊［］").replaceFrom(unescapeStr, "_");
        } catch (Exception e) {
            replaceStr="_";
        }
        return replaceStr;
    }
    private static List<Object[]> getTable(Sheet sheet) {
        logger.trace("sheet:{}, firstRowNum:{}, lastRowNum:{}", sheet.getSheetName(), sheet.getFirstRowNum(),
                sheet.getLastRowNum());
        List<Object[]> list = new ArrayList<>(sheet.getLastRowNum() + 1);
        int columnCount = 0;
        for (int r = sheet.getFirstRowNum(); r <= sheet.getLastRowNum(); r++) {
            Row row = sheet.getRow(r);
            if (row == null) {
                logger.trace("row:{}, null", r);
            } else {
                logger.trace("row:{}, firstCellNum:{}, lastCellNum:{}", row.getRowNum(), row.getFirstCellNum(),
                        row.getLastCellNum());
                if (row.getLastCellNum() <= 0) {
                    continue;
                }
                if (columnCount == 0) {
                    columnCount = row.getLastCellNum();
                }
                Object[] rowObj = new Object[columnCount];
                boolean hasValueRow = false;
                for (int c = row.getFirstCellNum(); c < row.getLastCellNum(); c++) {
                    Cell cell = row.getCell(c);
                    logger.trace("row:{}, cell:{}, value:{}", row.getRowNum(), c, cell);
                    rowObj[c] = getValueFromCell(cell);
                    if (!hasValueRow && (rowObj[c] != null && StringUtils.isNoneBlank(rowObj[c].toString()))) {
                        hasValueRow = true;
                    }
                }
                if (hasValueRow) {
                    list.add(rowObj);
                }
            }
        }
        return list;
    }

    public static final Object getValueFromCell(Cell cell) {
        if (cell == null) {
            return StringUtils.EMPTY;
        }
        Object value = null;
        switch (cell.getCellType()) {
            case Cell.CELL_TYPE_NUMERIC:
                if (DateUtil.isCellDateFormatted(cell)) {
                    value = cell.getDateCellValue();
                } else {
                    String cellFormat = cell.getCellStyle().getDataFormatString();
                    value = cell.getNumericCellValue();
                    if ("General".equals(cellFormat) || "@".equals(cellFormat)) {
                        cellFormat = "0";
                        DecimalFormat format = new DecimalFormat(cellFormat);
                        value = format.format(cell.getNumericCellValue());
                    }
                    
                }

                break;
            case Cell.CELL_TYPE_STRING:
                value = cell.getStringCellValue();

                break;
            case Cell.CELL_TYPE_FORMULA:
            	Double numericValue = null;
            	try{
            		numericValue = cell.getNumericCellValue();
            	}catch(IllegalStateException e){
            		value = cell.getStringCellValue();
            	}
                if (DateUtil.isValidExcelDate(numericValue)) { // 如果是日期类型
                    value = cell.getDateCellValue();
                } else {
                    value = String.valueOf(numericValue);
                    // System.out.println("formula value:" + value);
                }
                break;
            case Cell.CELL_TYPE_BLANK:
                value = StringUtils.EMPTY;
                break;
            case Cell.CELL_TYPE_BOOLEAN: // Boolean
                value = String.valueOf(cell.getBooleanCellValue());
                break;
            case Cell.CELL_TYPE_ERROR: // Error，返回错误码
                value = String.valueOf(cell.getErrorCellValue());
                break;
            default:
                value = StringUtils.EMPTY;
                break;
        }
        return value;
    }

    public static <T> void exportToExcel(HttpServletResponse response, List<T> data, String[] fields,
                                         String[] fieldValue) {
        exportToExcel(response, data, fields, fieldValue, null);
    }

    public static <T> void exportToExcel(HttpServletResponse response, List<T> data, String[] fields,
                                         String[] fieldValue, String fileName) {

        if (fileName == null || "".equals(fileName)) {
            fileName = System.currentTimeMillis() + ".xlsx";
        }

        response.setContentType("application/vnd.ms-excel");
        try {
            response.setHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(fileName, "utf-8"));
        } catch (UnsupportedEncodingException e1) {
            response.setHeader("Content-Disposition", "attachment; filename=" + fileName);
        }

        try {
            exportToExcel(response.getOutputStream(), data, fields, fieldValue);
        } catch (IOException e) {
            throw new RuntimeException("export data error", e);
        }
    }

    public static <T> ZipOutputStream getZipOutputStream(HttpServletResponse response, String fileName)
            throws IOException {

        if (fileName == null || "".equals(fileName)) {
            fileName = System.currentTimeMillis() + ".zip";
        }

        response.setContentType("application/zip");
        response.setHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(fileName, "utf-8"));
        ConvertUtils.register(new DateLocaleConverter(Locale.CHINA), Date.class);
        ZipOutputStream out = new ZipOutputStream(response.getOutputStream());
        return out;
    }

    public static <T> void exportToZip(ZipOutputStream out, List<T> data, String[] fields, String[] fieldValue,
                                       String fileName) {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        try {
            exportToExcel(baos, data, fields, fieldValue);

            out.putNextEntry(new ZipEntry("./tianxiao_export/" + fileName + ".xlsx"));
            out.write(baos.toByteArray());
            out.flush();
            out.closeEntry();
        } catch (IOException e) {
            throw new RuntimeException("export data error", e);
        } finally {
            IOUtils.closeQuietly(baos);
        }
    }

    public static <T> void closeZipOutputStream(ZipOutputStream out) {
        if (out != null) {
            try {
                out.flush();
                out.close();
            } catch (IOException e) {
            }
        }
    }

    private static CellStyle createCellStyle(Workbook workBook, String format, Map<String, CellStyle> cellStyleMap) {
        String key = EXPORT_CELL_STYLS + format;
        CellStyle cellStyle = cellStyleMap.get(key);
        if (cellStyle == null) {
            DataFormat dataFormat = workBook.createDataFormat();
            cellStyle = workBook.createCellStyle();
            cellStyle.setAlignment(CellStyle.ALIGN_CENTER);
            cellStyle.setDataFormat(dataFormat.getFormat(format));
            cellStyleMap.put(key, cellStyle);
        }
        return cellStyle;

    }

    private static void createCell(Sheet sheet, Row row, int column, Object value,
                                   Map<String, CellStyle> cellStyleMap) {
        Cell cell = row.createCell(column);

        if (value != null) {
            String format = null;
            if (value instanceof Date) {
                sheet.setColumnWidth(cell.getColumnIndex(), 20 * 256);
                format = EXPORT_DATE_FORMAT;
                cell.setCellValue((Date) value);
            } else {
                if (value instanceof Number && (((Number) value).longValue() < Integer.MAX_VALUE)) {
                    cell.setCellType(Cell.CELL_TYPE_NUMERIC);
                    if (value instanceof Double) {
                        format = "0.00";
                        cell.setCellValue(((Number) value).doubleValue());
                    } else {
                        format = "0";
                        cell.setCellValue(((Number) value).longValue());
                    }
                } else {
                    cell.setCellType(Cell.CELL_TYPE_STRING);
                    cell.setCellValue(value.toString());
                    format = "@";
                }
            }
            if (format != null) {
                cell.setCellStyle(createCellStyle(sheet.getWorkbook(), format, cellStyleMap));
            }
        } else {
            cell.setCellValue("");
        }
    }

    public static <T> void exportToExcel(OutputStream os, List<T> data, String[] fields, String[] fieldValue) {
        if (fields == null || fieldValue == null) {
            throw new RuntimeException("fields or header can't be null.");
        }
        Workbook wb = new XSSFWorkbook();
        Sheet sheet = wb.createSheet("ExportDataList");

        // Create a row and put some cells in it. Rows are 0 based.
        Row headerTitle = sheet.createRow(0);
        int index = 0;
        for (int i = 0; i < fields.length; i++) {
            Cell cell = headerTitle.createCell(index++ % fields.length);
            cell.setCellValue(fieldValue[i]);
            sheet.setColumnWidth(cell.getColumnIndex(), fieldValue[i].length() * 8 * 256);
            cell.getCellStyle().setAlignment(CellStyle.ALIGN_CENTER);
        }

        logger.debug("exportToExcel data size={}", data.size());
        try {
            Map<String, CellStyle> cellStyleMap = Maps.newHashMap();
            for (int i = 0; i < data.size(); i++) {
                Row row = sheet.createRow(i + 1);
                T o = data.get(i);

                for (int j = 0; j < fields.length; j++) {
                    try {
                        createCell(sheet, row, index++ % fields.length, propertyUtilsBean.getProperty(o, fields[j]),
                                cellStyleMap);
                    } catch (Exception e) {
                        e.printStackTrace();
                        throw new RuntimeException("export data error", e);
                    }

                }
            }
            wb.write(os);
            os.flush();
        } catch (IOException e) {
            throw new RuntimeException("export data error", e);
        } finally {
            IOUtils.closeQuietly(wb);
        }
    }

    public static void fillSheet(Sheet sheet, List<String> headers, Collection<Object[]> datas,
                                 Map<String, CellStyle> cellStyleMap) {
        Row headerTitle = sheet.createRow(0);
        int index = 0;
        for (int i = 0; i < headers.size(); i++) {
            String name = headers.get(i);
            int column = index++ % headers.size();
            sheet.setColumnWidth(column, name.length() * 2 * 256);
            Cell cell = headerTitle.createCell(column);
            cell.setCellValue(name);
            cell.getCellStyle().setAlignment(CellStyle.ALIGN_CENTER);
        }

        int i = 0;
        if (cellStyleMap == null) {
            cellStyleMap = Maps.newHashMap();
        }
        for (Object[] o : datas) {
            Row row = sheet.createRow(i + 1);

            for (int j = 0; j < o.length; j++) {
                try {
                    createCell(sheet, row, index++ % o.length, o[j], cellStyleMap);
                } catch (Exception e) {
                    throw new RuntimeException("export data error", e);
                }
            }
            i++;
        }
    }

    public static <T> void fillSheet(Sheet sheet, Collection<T> data, String[] fields, String[] fieldValue,
                                     Map<String, CellStyle> cellStyleMap) {
        // Create a row and put some cells in it. Rows are 0 based.
        Row headerTitle = sheet.createRow(0);
        int index = 0;
        for (int i = 0; i < fields.length; i++) {
            int column = index++ % fields.length;
            sheet.setColumnWidth(column, fieldValue[i].length() * 2 * 256);
            Cell cell = headerTitle.createCell(column);
            cell.setCellValue(fieldValue[i]);
            cell.getCellStyle().setAlignment(CellStyle.ALIGN_CENTER);
        }

        int i = 0;
        if (cellStyleMap == null) {
            cellStyleMap = Maps.newHashMap();
        }
        for (T o : data) {
            Row row = sheet.createRow(i + 1);

            for (int j = 0; j < fields.length; j++) {
                try {
                    createCell(sheet, row, index++ % fields.length, propertyUtilsBean.getProperty(o, fields[j]),
                            cellStyleMap);
                } catch (Exception e) {
                    throw new RuntimeException("export data error", e);
                }
            }
            i++;
        }
    }

}
